#! /bin/sh
#
# mountpvfs2 Mount all the "auto" PVFS2 filesystems at boot.
# optionally may mount "noauto" PVFS2 volumes too.
# PVFS2 client must be running.
# 
#
# Version:	mountpvfs2  1.00  
#
# chkconfig: 2345 37 57

# Source function library.
. /lib/lsb/init-functions

KERNEL=`uname -s`
umask 022

# subs
domount () {
	# domount [noauto]
	
	OPTS=
	if [ -f /etc/pvfs2tab ]
	then
		exec 9<&0 0</etc/pvfs2tab
		while read FDEV FDIR FTYPE FOPTS REST
		do
			case "$FDEV" in
				""|\#*)
					continue
					;;
			esac
			
			if [ "$FTYPE" != "pvfs2" ];
				then 
				continue
			fi
			
			case "$FOPTS" in
				noauto|*,noauto|noauto,*|*,noauto,*)
					if [ "$1" != "noauto" ];
						then
						continue
					fi										
					;;
				?*)
					OPTS="-o$FOPTS"
					;;
			esac
			
			# Is the mountpoint present?
			if [ ! -d $FDIR ]
			then
				log_action_msg " Failed"
				log_failure_msg "PVFS2 mountpoint '$FDIR' not found."
				exit 1
			fi
			# now mount it if it's not mounted yet
			if ! mountpoint -q $FDIR
			then
				# No, do it now
				mount -t pvfs2 $OPTS $FDEV $FDIR
				if [ $? != 0 ];
				then
					log_action_msg " Failed"
					log_failure_msg "PVFS2 : can't mount '$FDIR'"
					exit 2
				fi
			fi
		done
		exec 0<&9 9<&-
	fi

}

pvfsclientstatus () {
	/etc/init.d/pvfs2-client status > /tmp/$$.status
	CLISTAT=`cat /tmp/$$.status`
	rm /tmp/$$.status
	
	case "$CLISTAT" in
		*"Running with PID"*)
			return 0
		;;
		*"Not running"*)
			log_failure_msg "pvfs2-client not running"
			exit 3
		;;
	esac
	log_failure_msg "pvfs2-client status unavailable"
	exit 99
}

# main
case "$1" in
    start|"")
		log_daemon_msg "mounting PVFS2 filesystems"
		# check pvfs2-client status
		pvfsclientstatus
		domount
		log_success_msg
        ;;
    restart|reload|force-reload)
        echo "Error: argument '$1' not supported" >&2
        exit 3
        ;;
    stop)
        ;;
	all)
		log_daemon_msg "mounting PVFS2 filesystems"
		# check pvfs2-client status
		pvfsclientstatus
		domount noauto
		log_success_msg
  	;;
    *)
        echo "Usage: $0 start|all|stop" >&2
        exit 3
        ;;
esac

: exit 0
